@@ -10,6 +10,7 @@ Usage::
     ```
 """
 import sys
+from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -20,6 +21,7 @@ else:
 __all__ = (
     "DeleteThingShadowResponseTypeDef",
     "GetThingShadowResponseTypeDef",
+    "ListNamedShadowsForThingResponseTypeDef",
     "UpdateThingShadowResponseTypeDef",
 )
 
@@ -29,6 +31,12 @@ GetThingShadowResponseTypeDef = TypedDict(
     "GetThingShadowResponseTypeDef", {"payload": bytes}, total=False
 )
 
+ListNamedShadowsForThingResponseTypeDef = TypedDict(
+    "ListNamedShadowsForThingResponseTypeDef",
+    {"results": List[str], "nextToken": str, "timestamp": int},
+    total=False,
+)
+
 UpdateThingShadowResponseTypeDef = TypedDict(
     "UpdateThingShadowResponseTypeDef", {"payload": bytes}, total=False
 )
